@@ -86,7 +86,10 @@ class DruidHook(BaseHook):
         """Get Druid connection url."""
         host = self.conn.host
         port = self.conn.port
-        conn_type = self.conn.conn_type or "http"
+        if self.conn.schema:
+            conn_type = self.conn.schema
+        else:
+            conn_type = self.conn.conn_type or "http"
         if ingestion_type == IngestionType.BATCH:
             endpoint = self.conn.extra_dejson.get("endpoint", "")
         else:
@@ -196,7 +199,7 @@ class DruidDbApiHook(DbApiHook):
 
     def get_conn(self) -> connect:
         """Establish a connection to druid broker."""
-        conn = self.get_connection(getattr(self, self.conn_name_attr))
+        conn = self.get_connection(self.get_conn_id())
         druid_broker_conn = connect(
             host=conn.host,
             port=conn.port,
@@ -215,7 +218,7 @@ class DruidDbApiHook(DbApiHook):
 
         e.g: druid://localhost:8082/druid/v2/sql/
         """
-        conn = self.get_connection(getattr(self, self.conn_name_attr))
+        conn = self.get_connection(self.get_conn_id())
         host = conn.host
         if conn.port is not None:
             host += f":{conn.port}"
